@@ -121,11 +121,15 @@ class EmpresaLog(models.Model):
 
 
 class ContatoLog(models.Model):
-    celular = models.CharField(max_length=50, null=True)
+    celular_numero = models.CharField(max_length=50, null=True)
     celular_ddd = models.CharField(max_length=3, null=True)
+    celular_completo = models.CharField(max_length=50, null=True)
+    celular_completo_form = models.CharField(max_length=50, null=True)
 
-    telefone = models.CharField(max_length=50, null=True)
+    telefone_numero = models.CharField(max_length=50, null=True)
     telefone_ddd = models.CharField(max_length=3, null=True)
+    telefone_completo = models.CharField(max_length=50, null=True)
+    telefone_completo_form = models.CharField(max_length=50, null=True)
 
     email = models.EmailField(max_length=200, null=True)
 
